pub struct IndentHeuristic<IndentOfToken> { /* private fields */ }Expand description
A slider heuristic that uses indentation levels to determine the best hunk position.
This heuristic analyzes the indentation of lines surrounding potential hunk positions and chooses the position that results in the most intuitive diff for human readers. It’s particularly effective for code and other indented text.
Implementations